@@ -8,7 +8,7 @@
 
 
 load.corpus <-
-function(files, corpus.dir = "", encoding = "native.enc") {
+function(files = "all", corpus.dir = "", encoding = "native.enc") {
   # first of all, retrieve the current path name
   original.path = getwd()
   # checking if the specified directory exists
@@ -25,6 +25,11 @@ function(files, corpus.dir = "", encoding = "native.enc") {
     # if the argument was empty, then relax
     cat("using current directory...\n")
   }
+  # now, checking which files were requested; usually, the user is 
+  # expected to specify a vector with samples' names
+  if(length(files) == 1 & files[1] == "all") {
+  	  files = list.files()
+  }
   # variable initialization
   loaded.corpus = list()
   # uploading all files listed in the vector "files"
