@@ -1,4 +1,4 @@
-# Delta in its various flavours
+# Delta in its various flavors
 
 perform.delta = function(training.set, 
                          test.set,
@@ -11,12 +11,26 @@ perform.delta = function(training.set,
 
 
 
-# getting the number of features (e.g. MFWs)
-no.of.cols = length(training.set[1,])
+
+# first, sanitizing the type of input data
+if(length(dim(training.set)) != 2) {
+    stop("train set error: a 2-dimensional table (matrix) is required")
+}
+# if a vector (rather than a matrix) was used as a test set, a fake row
+# will be added; actually, this will be a duplicate of the vector
+if(is.vector(test.set) == TRUE) {
+    test.set = rbind(test.set, test.set)
+    rownames(test.set) = c("unknown", "unknown-copy")
+    # additionally, duplicating ID of the test classes (if specified)
+    if(length(classes.test.set) == 1) {
+        classes.test.set = c(classes.test.set, "unknown-copy")
+    }
+}
+
 
 # checking if the two sets are of the same size
-if(length(test.set[1,]) != no.of.cols) {
-        stop("training set and test set should the same number of variables!")
+if(length(test.set[1,]) != length(training.set[1,]) ) {
+        stop("training set and test set must have the same number of variables!")
 }
 
 
@@ -153,6 +167,14 @@ for(h in 1:length(selected.dist[,1])) {
         classification.rankings = rbind(classification.rankings, current.ranking)
 }
 
+# preparing a confusion table
+predicted_classes = classification.results
+actual_classes = classes.test.set
+confusion.matrix = table(predicted_classes, actual_classes)
+# getting rid of the classes not represented in the training set (e.g. anonymous samples)
+# confusion.matrix = confusion.matrix[,rownames(confusion.matrix)]
+
+
 names(classification.results) = rownames(test.set)
 rownames(classification.rankings) = rownames(test.set)
 rownames(classification.scores) = rownames(test.set)
@@ -162,6 +184,8 @@ colnames(classification.scores) = 1:no.of.candidates
 attr(classification.results, "distance.table") = selected.dist
 attr(classification.results, "rankings") = classification.rankings
 attr(classification.results, "scores") = classification.scores
+attr(classification.results, "confusion_matrix") = confusion.matrix
+
 
 return(classification.results)
 }
